import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges } from '@angular/core';
import { DrawerService } from '../service/drawer.service';
import { StateListener } from '../state-listener.component';
import { Directionality } from '@angular/cdk/bidi';
import { Subscription } from 'rxjs';
import { MatDrawerMode } from '@angular/material/sidenav';
import * as i0 from "@angular/core";
export declare type DrawerLayoutVariantType = 'permanent' | 'persistent' | 'temporary' | 'rail';
/**
 * [DrawerLayout Component](https://brightlayer-ui-components.github.io/angular/?path=/info/components-drawer--readme)
 *
 * The `<blui-drawer-layout>` component is a wrapper around the [Angular Material Sidenav](https://material.angular.io/components/sidenav/overview) that adds specific Brightlayer UI functionality and styling.
 * The `<blui-drawer-layout>` component is used to provide the appropriate resizing behavior for your main application content when used in conjunction with a Brightlayer UI `<blui-drawer>`.
 * It accepts a drawer and content as child elements;
 */
export declare class DrawerLayoutComponent extends StateListener implements AfterViewInit, OnChanges {
    private readonly _dir;
    /** Controls how the Drawer behaves and appears on the screen.  Can be `permanent` | `peristent` | `temporary` | `rail`.
     *
     * `permanent` - `Drawer` appears on the side of the screen and cannot be dismissed.
     *
     * `persistent` - `Drawer` appears on the side of the screen and responds to the `open` @Input. When closed, only shows each `NavItem` icon.
     *
     * `temporary` - `Drawer` slides in from the side of the screen and appears as an overlay.
     *
     * `rail` - `Drawer` appears on the side of the screen as a slim element, supporting icons and text.
     *
     * @default temporary
     * */
    variant: DrawerLayoutVariantType;
    /** Drawer pixel width
     *
     * @default 350
     * */
    width: number;
    /** Event triggered on 'temporary' variant backdrop click */
    backdropClick: EventEmitter<void>;
    remElement: ElementRef;
    isRtl: boolean;
    remSizePx: number;
    dirChangeSubscription: Subscription;
    content: HTMLElement;
    constructor(drawerService: DrawerService, changeDetectorRef: ChangeDetectorRef, _dir: Directionality);
    ngAfterViewInit(): void;
    ngOnChanges(): void;
    ngOnDestroy(): void;
    getMode(): MatDrawerMode;
    toRem(px: number): number;
    hasSideBorder(): boolean;
    closeDrawer(): void;
    isDrawerVisible(): boolean;
    getContentMargin(): number;
    getCollapsedWidth(): number;
    isCollapsed(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<DrawerLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DrawerLayoutComponent, "blui-drawer-layout", never, { "variant": "variant"; "width": "width"; }, { "backdropClick": "backdropClick"; }, never, ["[blui-drawer]", "[blui-content]"]>;
}
